# Changelog

All notable changes to this project will be documented in this file. See [commit-and-tag-version](https://github.com/absolute-version/commit-and-tag-version) for commit guidelines.

## [1.1.2](https://github.com/WAS-Insurance/paypal_python_sdk/compare/v1.1.0...v1.1.1) (2025-05-10)
* Fixed import directives ([56a7617](https://github.com/WAS-Insurance/paypal_python_sdk/commit/56a76173d026701313c84fc13ba3dcc60f555456))

## [1.1.1](https://github.com/WAS-Insurance/paypal_python_sdk/compare/v1.1.0...v1.1.1) (2025-05-10)


### Bug Fixes

* Renamed package to fix imports ([4d63929](https://github.com/WAS-Insurance/paypal_python_sdk/commit/4d639294afc324fdaaa09c318c642986e747705f))
